from flask import Flask, request
from flask_socketio import SocketIO, emit, join_room, rooms
import requests

from gencode import make_code
from game import Game

app = Flask('venture')
socketio = SocketIO(app, cors_allowed_origins="*")

games = {}

@socketio.on('new-game')
def on_newgame():
    data = {}
    code = make_code()
    games[code] = Game(code)
    join_room(code)
    emit('set-code', {'code': code})

## Contestant

@socketio.on('contestant-join')
def on_join_contestant(data):
    sid = request.sid
    signature = data['signature']
    room = data['room']
    join_room(room)
    games[room].add_contestant(sid, signature)
    emit('contestant-joined', {'sid': sid, 'signature': signature }, to=room)

## Host

@socketio.on('host-join')
def on_join_host(data):
    sid = request.sid
    room = data['room']
    join_room(room)
    games[room].add_host(sid)
    emit('host-joined', {'sid': sid}, to=room)

@socketio.on('host-start')
def on_host_start():
    room = rooms()[0]
    game = games[room]
    game.get_questions()
    emit('categories', [c.name for c in game.categories[:6]], to=room)

def main():
    socketio.run(app, host='0.0.0.0', debug=True)

if __name__ == '__main__':
    main()
